@@ -7,8 +7,9 @@
 #' @examples
 #' dk_pct_to_num_half_life(pct_lost = 93.75)
 #' @export
-dk_pct_to_num_half_life <- function(pct_lost){
-  if(!is.numeric(pct_lost)) 
+dk_pct_to_num_half_life <- function(pct_lost) {
+  if (!is.numeric(pct_lost)) {
     stop("pct_lost must be a number.")
-    -log(1 - pct_lost / 100) / log(2)
+  }
+  -log(1 - pct_lost / 100) / log(2)
 }
